@@ -29,7 +29,7 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: ieee80211.c 1666 2006-07-04 10:22:11Z kelmo $
+ * $Id: ieee80211.c 2109 2007-02-14 03:40:19Z scottr $
  */
 #ifndef EXPORT_SYMTAB
 #define	EXPORT_SYMTAB
@@ -38,7 +38,9 @@
 /*
  * IEEE 802.11 generic handler
  */
+#ifndef AUTOCONF_INCLUDED
 #include <linux/config.h>
+#endif
 #include <linux/version.h>
 #include <linux/module.h>
 #include <linux/skbuff.h>
@@ -398,7 +400,7 @@ ieee80211_vap_setup(struct ieee80211com *ic, struct net_device *dev,
 	dev->set_mac_address = ieee80211_set_mac_address;
 #endif
  	dev->change_mtu = ieee80211_change_mtu;
-	dev->tx_queue_len = 0;			/* NB: bypass queueing */
+	dev->tx_queue_len = 0;			/* NB: bypass queuing */
 	dev->hard_header_len = parent->hard_header_len;
 	/*
 	 * The caller is assumed to allocate the device with
@@ -502,6 +504,9 @@ ieee80211_vap_setup(struct ieee80211com *ic, struct net_device *dev,
 	vap->iv_dtim_period = IEEE80211_DTIM_DEFAULT;
 	vap->iv_des_chan = IEEE80211_CHAN_ANYC;	/* any channel is ok */
 
+	vap->iv_monitor_crc_errors = 0;
+	vap->iv_monitor_phy_errors = 0;
+
 	IEEE80211_ADDR_COPY(vap->iv_myaddr, ic->ic_myaddr);
 	/* NB: defer setting dev_addr so driver can override */
 
@@ -1114,7 +1119,7 @@ ieee80211com_media_change(struct net_device *dev)
 			KASSERT(vap->iv_bss != NULL, ("no bss node"));
 			vap->iv_bss->ni_rates = ic->ic_sup_rates[newphymode];
 		}
-		error = ENETRESET;
+		error = -ENETRESET;
 	}
 	IEEE80211_UNLOCK_IRQ(ic);
 
@@ -1141,7 +1146,7 @@ findrate(struct ieee80211com *ic, enum ieee80211_phymode mode, int rate)
 /*
  * Convert a media specification to a rate index and possibly a mode
  * (if the rate is fixed and the mode is specified as ``auto'' then
- * we need to lock down the mode so the index is meanginful).
+ * we need to lock down the mode so the index is meaningful).
  */
 static int
 checkrate(struct ieee80211com *ic, enum ieee80211_phymode mode, int rate)
@@ -1208,11 +1213,11 @@ ieee80211_media_change(struct net_device *dev)
 	error = 0;
 	if (vap->iv_fixed_rate != newrate) {
 		vap->iv_fixed_rate = newrate;		/* fixed tx rate */
-		error = ENETRESET;
+		error = -ENETRESET;
 	}
 	if (vap->iv_des_mode != newmode) {
 		vap->iv_des_mode = newmode;		/* desired phymode */
-		error = ENETRESET;
+		error = -ENETRESET;
 	}
 	return error;
 }
